==> frourio-express-0.27.1.tgz: package/README.md <==
# frourio-express
<br />
<img src="https://frouriojs.github.io/frourio/assets/images/ogp.png" width="1280" alt="frourio-express" />

<div align="center">
  <a href="https://www.npmjs.com/package/frourio-express">
    <img src="https://img.shields.io/npm/v/frourio-express" alt="npm version" />
  </a>
  <a href="https://www.npmjs.com/package/frourio-express">
    <img src="https://img.shields.io/npm/dm/frourio-express" alt="npm download" />
  </a>
  <a href="https://github.com/frouriojs/frourio-express/actions?query=workflow%3A%22Node.js+CI%22">
    <img src="https://github.com/frouriojs/frourio-express/workflows/Node.js%20CI/badge.svg?branch=main" alt="Node.js CI" />
  </a>
  <a href="https://codecov.io/gh/frouriojs/frourio-express">
    <img src="https://img.shields.io/codecov/c/github/frouriojs/frourio-express.svg" alt="Codecov" />
  </a>
  <a href="https://lgtm.com/projects/g/frouriojs/frourio-express/context:javascript">
    <img src="https://img.shields.io/lgtm/grade/javascript/g/frouriojs/frourio-express.svg" alt="Language grade: JavaScript" />
  </a>
</div>

<p align="center">Fast and type-safe full stack framework, for TypeScript</p>
<br />
<br />
<br />

## Why frourio-express ?

Even if you write both the frontend and backend in TypeScript, you can't statically type-check the API's sparsity.

We are always forced to write "Two TypeScript".  
We waste a lot of time on dynamic testing using the browser and server.

<div align="center">
   <img src="https://frourio.io/img/TwoTS.svg" width="1200" alt="Why frourio ?" />
</div>
<br />
<br />

Frourio-express is a framework for developing web apps quickly and safely in **"One TypeScript"**.

<div align="center">
   <img src="https://frourio.io/img/OneTS.svg" width="1200" alt="Architecture of create-frourio-app" />
</div>
<br />
<br />

## Documents

https://frourio.com/docs

## License

Frourio-express is licensed under a [MIT License](./LICENSE).

==> frourio-express-0.31.0.tgz: package/README.md <==
# frourio-express

<br />
<img src="https://frouriojs.github.io/frourio/assets/images/ogp.png" width="1280" alt="frourio-express" />

<div align="center">
  <a href="https://www.npmjs.com/package/frourio-express">
    <img src="https://img.shields.io/npm/v/frourio-express" alt="npm version" />
  </a>
  <a href="https://www.npmjs.com/package/frourio-express">
    <img src="https://img.shields.io/npm/dm/frourio-express" alt="npm download" />
  </a>
  <a href="https://github.com/frouriojs/frourio-express/actions?query=workflow%3A%22Node.js+CI%22">
    <img src="https://github.com/frouriojs/frourio-express/workflows/Node.js%20CI/badge.svg?branch=main" alt="Node.js CI" />
  </a>
  <a href="https://codecov.io/gh/frouriojs/frourio-express">
    <img src="https://img.shields.io/codecov/c/github/frouriojs/frourio-express.svg" alt="Codecov" />
  </a>
  <a href="https://lgtm.com/projects/g/frouriojs/frourio-express/context:javascript">
    <img src="https://img.shields.io/lgtm/grade/javascript/g/frouriojs/frourio-express.svg" alt="Language grade: JavaScript" />
  </a>
</div>

<p align="center">Fast and type-safe full stack framework, for TypeScript</p>
<br />
<br />
<br />

## Why frourio-express ?

Even if you write both the frontend and backend in TypeScript, you can't statically type-check the API's sparsity.

We are always forced to write "Two TypeScript".  
We waste a lot of time on dynamic testing using the browser and server.

<div align="center">
   <img src="https://frourio.com/img/TwoTS.svg" width="1200" alt="Why frourio ?" />
</div>
<br />
<br />

Frourio-express is a framework for developing web apps quickly and safely in **"One TypeScript"**.

<div align="center">
   <img src="https://frourio.com/img/OneTS.svg" width="1200" alt="Architecture of create-frourio-app" />
</div>
<br />
<br />

## Documents

https://frourio.com/docs

## License

Frourio-express is licensed under a [MIT License](./LICENSE).
